<!--- begin start mode --->
<cfswitch expression="#ThisTag.ExecutionMode#">


	<cfcase value="start">
	
		<cfset variables.sVars = structNew() />
		
		<cfset variables.sVars.Error = "" />
		<cfset variables.sVars.lcValidUnits = "m,s" />
		<cfset variables.sVars.lcvalidImageFormats = "png" />
		<cfset variables.sVars.lcImageSizes = "small,medium,large" />
		<cfset variables.sVars.lcImageSizesValues = "31,61,93" />
		
		<!--- must have a closing tag --->
		<cfif Not ThisTag.HasEndTag>
			<cfset variables.sVars.Error = variables.sVars.Error & "<li>A closing tag for CF_WEATHER is needed</li>" />
		</cfif>
		<cfif Not StructKeyExists(attributes, "locationCode")>
			<cfset variables.sVars.Error = variables.sVars.Error & "<li>The 'locationCode' attribute is needed</li>" />
		</cfif>
		<cfif Not StructKeyExists(attributes, "partnerID")>
			<cfset variables.sVars.Error = variables.sVars.Error & "<li>The 'partnerID' attribute is needed</li>" />
		</cfif>
		<cfif Not StructKeyExists(attributes, "licenseKey")>
			<cfset variables.sVars.Error = variables.sVars.Error & "<li>The 'licenseKey' attribute is needed</li>" />
		</cfif>
		<cfif StructKeyExists(attributes, "unit")>
			<cfif Not ListFind(variables.sVars.lcValidUnits, attributes.unit)>
				<cfset variables.sVars.Error = variables.sVars.Error & "<li>Valid parameters for the 'unit' attribute are 'm' and 's' only</li>" />
			</cfif>
		</cfif>
		<cfif StructKeyExists(attributes, "imageSize")>
			<cfif Not ListFind(variables.sVars.lcImageSizes, attributes.imageSize)>
				<cfset variables.sVars.Error = variables.sVars.Error & "<li>Valid parameters for the 'imageSize' attribute are 'small', 'medium' and 'large' only</li>" />
			</cfif>
		</cfif>
		<cfif StructKeyExists(attributes, "imageType")>
			<cfif Not ListFind(variables.sVars.lcvalidImageFormats, attributes.imageType)>
				<cfset variables.sVars.Error = variables.sVars.Error & "<li>Valid parameters for the 'imageType' attribute are 'png' only</li>" />
			</cfif>
		</cfif>
		<cfif StructKeyExists(attributes, "daysForecast")>
			<cfif Not IsNumeric(attributes.daysForecast)>
				<cfset variables.sVars.Error = variables.sVars.Error & "<li>The 'daysForecast' attribute is not of type numeric</li>" />
			<cfelse>
				<cfif ((attributes.daysForecast LTE 0) Or (attributes.daysForecast GT 5))>
					<cfset variables.sVars.Error = variables.sVars.Error & "<li>The 'daysForecast' value must be between 1 and 5</li>" />
				</cfif>
			</cfif>
		</cfif>
		<cfif StructKeyExists(attributes, "cacheSeconds")>
			<cfif Not IsNumeric(attributes.cacheSeconds)>
				<cfset variables.sVars.Error = variables.sVars.Error & "<li>The 'cacheSeconds' attribute is not of type numeric</li>" />
			<cfelse>
				<cfif attributes.cacheSeconds LT 0>
					<cfset variables.sVars.Error = variables.sVars.Error & "<li>The 'cacheSeconds' value must be greater than or equal to 0</li>" />
				</cfif>
			</cfif>
		</cfif>
		
		<!--- print out the error messages --->
		<cfif Len(Trim(variables.sVars.Error))>
			<strong>The following Errors have been detected in CF_WEATHER</strong>
			<ol>
				<cfoutput>#variables.sVars.Error#</cfoutput>
			</ol>
			<cfexit />
		</cfif>
		
		<cfparam name="attributes.imageLocation" type="string" default="/weather/images/" />
		<cfparam name="attributes.imageSize" type="string" default="medium" />
		<cfparam name="attributes.imageType" type="string" default="png" />
		<cfparam name="attributes.locationCode" type="string" default="" />
		<cfparam name="attributes.partnerID" type="string" default="" />
		<cfparam name="attributes.licenseKey" type="string" default="" />
		<cfparam name="attributes.daysForecast" type="numeric" default="5" />
		<cfparam name="attributes.xmlFolder" type="string" default="#ExpandPath('.')#" />
		<cfparam name="attributes.xmlFile" type="string" default="weather" />
		<cfparam name="attributes.unit" type="string" default="s" />
		<cfparam name="attributes.cacheSeconds" type="numeric" default="3600" />
		<cfparam name="attributes.proxyServer" type="string" default="" />
		<cfparam name="attributes.proxyPort" type="string" default="" />
		<cfparam name="attributes.proxyUser" type="string" default="" />
		<cfparam name="attributes.proxyPassword" type="string" default="" />
		
		<cfset caller.sWeather = structNew() />
		<cfset caller.sWeather.sParams = structNew() />
		
		<cfset caller.sWeather = _init(
													attributes.locationCode, 
													attributes.partnerID, 
													attributes.licenseKey, 
													attributes.unit, 
													attributes.daysForecast, 
													attributes.xmlFolder, 
													attributes.xmlFile, 
													attributes.cacheSeconds,
													attributes.proxyServer,
													attributes.proxyPort,
													attributes.proxyUser,
													attributes.proxyPassword) />
		<cfset caller.sWeather.sParams.imageLocation = attributes.imageLocation />
		<cfset caller.sWeather.sParams.imageSize = listGetAt(variables.sVars.lcImageSizesValues, ListFind(variables.sVars.lcImageSizes, attributes.imageSize)) />
		<cfset caller.sWeather.sParams.imageType = attributes.imageType />
		<cfset caller.sWeather.sParams.locationCode = attributes.locationCode />
		<cfset caller.sWeather.sParams.partnerID = attributes.partnerID />
		<cfset caller.sWeather.sParams.licenseKey = attributes.licenseKey />
		<cfset caller.sWeather.sParams.daysForecast = attributes.daysForecast />
		<cfset caller.sWeather.sParams.xmlFolder = attributes.xmlFolder />
		<cfset caller.sWeather.sParams.xmlFile = attributes.xmlFile />
		<cfset caller.sWeather.sParams.unit = attributes.unit />
		<cfset caller.sWeather.sParams.cacheSeconds = attributes.cacheSeconds />
		<cfset caller.sWeather.sParams.proxyServer = attributes.proxyServer />
		<cfset caller.sWeather.sParams.proxyPort = attributes.proxyPort />
		<cfset caller.sWeather.sParams.proxyUser = attributes.proxyUser />
		<cfset caller.sWeather.sParams.proxyPassword = attributes.proxyPassword />
		
	</cfcase>


	<cfcase value="end">
	</cfcase>


</cfswitch>


<!---
SUPPORTING FUNCTIONS
/--->
<cffunction name="_init" access="private" output="false" returntype="struct">
	<cfargument name="cLocation" required="true" type="string" />
	<cfargument name="cPartner" required="true" type="string" />
	<cfargument name="cKey" required="true" type="string" />
	<cfargument name="cUnit" required="true" type="string" />
	<cfargument name="iDaysForecast" required="true" type="numeric" />
	<cfargument name="cXmlFolder" required="true" type="string" />
	<cfargument name="cXmlFile" required="true" type="string" />
	<cfargument name="iCacheSeconds" required="true" type="numeric" />
	<cfargument name="cProxyServer" required="true" type="string" />
	<cfargument name="cProxyPort" required="true" type="string" />
	<cfargument name="cProxyUser" required="true" type="string" />
	<cfargument name="cProxyPassword" required="true" type="string" />
	
	<cfset var sVars = structNew() />
	
	<cfset sVars.cUrl = "" />
	<cfset sVars.cHttpContent = "" />
	<cfset sVars.cAbsoluteFileLocation = "" />
	<cfset sVars.bNeedsRefresh = false />
	<cfset sVars.xmlContents = "" />
	<cfset sVars.sWeather = structNew() />
	
	<cfset sVars.bNeedsRefresh = _needsRefresh(arguments.cXmlFolder, arguments.cXmlFile, arguments.cUnit, arguments.iCacheSeconds) />
	<!--- create xml url /--->
	<cfset sVars.cUrl = _createUrl(arguments.cLocation, arguments.cPartner, arguments.cKey, arguments.cUnit, arguments.iDaysForecast) />
	<cfif sVars.bNeedsRefresh>
		<!--- get http content /--->
		<cfset sVars.cHttpContent = _getHttpContent(sVars.cUrl, arguments.cProxyServer, arguments.cProxyPort, arguments.cProxyUser, arguments.cProxyPassword) />
		<!--- write http content to disk /--->
		<cfset _writeXml(arguments.cXmlFolder, arguments.cXmlFile, arguments.cUnit, sVars.cHttpContent) />
	</cfif>
	<!--- read contents from file /--->
	<cfset sVars.cAbsoluteFileLocation = _fixAbsoluteFileLocation(arguments.cXmlFolder, arguments.cXmlFile) & "_" & arguments.cUnit & ".xml" />
	<cfset sVars.xmlContents = _readFile(sVars.cAbsoluteFileLocation) />
	<!--- parse xml and create structure /--->
	<cfset sVars.sWeather = _parseXml(sVars.xmlContents, arguments.iDaysForecast, sVars.cUrl) />
	
	<cfreturn sVars.sWeather />
</cffunction>


<cffunction name="_createUrl" access="private" output="false" returntype="string">
	<cfargument name="location" required="true" type="string" />
	<cfargument name="partner" required="true" type="string" />
	<cfargument name="key" required="true" type="string" />
	<cfargument name="unit" required="false" type="string" default="m" />
	<cfargument name="daysForecast" required="false" type="numeric" default="5" />
	
	<cfset var sVars = structNew() />
	
	<cfset sVars.cUrl = "http://xoap.weather.com/weather/local/" />
	<cfset sVars.cCC = "*" />
	<cfset sVars.iDaysForecast = arguments.daysForecast />
	
	<cfif arguments.daysForecast GT 5>
		<cfset sVars.iDaysForecast = 5 />
	</cfif>
	<cfif arguments.daysForecast LT 0>
		<cfset sVars.iDaysForecast = 5 />
	</cfif>
	
	<cfset sVars.cUrl = "#sVars.cUrl##arguments.location#?cc=#sVars.cCC#&dayf=#sVars.iDaysForecast#&link=xoap&prod=xoap&par=#arguments.partner#&key=#arguments.key#&unit=#arguments.unit#" />

	<cfreturn sVars.cUrl />
</cffunction>


<cffunction name="_getHttpContent" access="private" output="false" returntype="string">
	<cfargument name="cUrl" required="true" type="string" />
	<cfargument name="cProxyServer" required="false" type="string" />
	<cfargument name="cProxyPort" required="false" type="string" />
	<cfargument name="cProxyUser" required="false" type="string" />
	<cfargument name="cProxyPassword" required="false" type="string" />
	
	<cfset var sVars = structNew() />
	
	<cfset sVars.cUrlContents = "" />
	
	<cfif Len(arguments.cProxyServer) AND Len(arguments.cProxyPort)>
		<cfhttp method="GET" 
			url="#arguments.cUrl#" 
			resolveurl="false" 
			timeout="30" 
			proxyserver="#arguments.cProxyServer#" 
			proxyport="#arguments.cProxyPort#" 
			proxyuser="#arguments.cProxyUser#" 
			proxypassword="#arguments.cProxyPassword#">
		</cfhttp>
	<cfelse>
		<cfhttp method="GET" url="#arguments.cUrl#" resolveurl="false" timeout="10"></cfhttp>
	</cfif>
	<cfif cfhttp.Statuscode IS "200 OK">
		<cfset sVars.cUrlContents = cfhttp.FileContent />
	</cfif>
	
	<cfreturn sVars.cUrlContents />
</cffunction>


<cffunction name="_writeXml" access="private" output="false">
	<cfargument name="cFolder" required="true" type="string" />
	<cfargument name="cFile" required="true" type="string" />
	<cfargument name="cUnit" required="true" type="string" />
	<cfargument name="cContents" required="true" type="string" />
	
	<cfset var sVars = structNew() />
	
	<cfset sVars.cFileLocation = "" />
	
	<cfset sVars.cFileLocation = _fixAbsoluteFileLocation(arguments.cFolder, arguments.cFile) />
	<cffile action="WRITE" file="#sVars.cFileLocation#_#arguments.cUnit#.xml" nameconflict="OVERWRITE" output="#arguments.cContents#" />
</cffunction>


<cffunction name="_fixAbsoluteFileLocation" access="private" output="false" returntype="string">
	<cfargument name="cFolder" required="true" type="string" />
	<cfargument name="cFile" required="true" type="string" />
	
	<cfset var sVars = structNew() />
	
	<cfset sVars.cFileLocation = "" />
	
	<cfif right(arguments.cFolder, 1) EQ "\">
		<cfset sVars.cFileLocation = arguments.cFolder & arguments.cFile />
	<cfelse>
		<cfset sVars.cFileLocation = arguments.cFolder & "\" & arguments.cFile />
	</cfif>
	
	<cfreturn sVars.cFileLocation />
</cffunction>


<cffunction name="_needsRefresh" access="private" output="false" returntype="boolean">
	<cfargument name="cXmlFolder" required="true" type="string" />
	<cfargument name="cFileName" required="true" type="string" />
	<cfargument name="cUnit" required="true" type="string" />
	<cfargument name="iSeconds" required="true" type="numeric" />
	
	<cfset var sVars = structNew() />
	
	<cfset sVars.bNeedsRefresh = false />
	<cfset sVars.qDirectoryContents = queryNew("empty") />
	<cfset sVars.cAbsoluteFileLocation = _fixAbsoluteFileLocation(arguments.cXmlFolder, arguments.cFileName) />
	
	<cfif FileExists(sVars.cAbsoluteFileLocation & "_" & arguments.cUnit & ".xml")>
		<cfdirectory action="list" directory="#arguments.cXmlFolder#" name="sVars.qDirectoryContents" filter="#arguments.cFileName#_#arguments.cUnit#.xml" />
		<cfif Abs(DateDiff("s", sVars.qDirectoryContents.dateLastModified, now())) GT arguments.iSeconds>
			<cfset sVars.bNeedsRefresh = true />
		</cfif>
	<cfelse>
		<cfset sVars.bNeedsRefresh = true />
	</cfif>
	
	<cfreturn sVars.bNeedsRefresh />
</cffunction>


<cffunction name="_readFile" access="private" output="false" returntype="string">
	<cfargument name="cAbsoluteFileLocation" required="true" type="string" />
	
	<cfset var sVars = structNew() />
	
	<cfset sVars.cFileContents = "" />
	
	<cffile action="read" file="#arguments.cAbsoluteFileLocation#" variable="sVars.cFileContents" />
	
	<cfreturn sVars.cFileContents />
</cffunction>



<cffunction name="_parseXml" access="private" output="false" returntype="struct">
	<cfargument name="cXml" required="true" type="string" />
	<cfargument name="iDaysForecast" required="true" type="numeric" />
	<cfargument name="cUrl" required="true" type="string" />
	
	<cfset var sVars = structNew() />
	
	<cfset sVars.xmlDoc = xmlParse(arguments.cXml) />
	<cfset sVars.sProperties = xmlSearch(sVars.xmlDoc, "/weather/head") />
	<cfset sVars.sLocation = xmlSearch(sVars.xmlDoc, "/weather/loc") />
	<cfset sVars.sCurrentConditions = xmlSearch(sVars.xmlDoc, "/weather/cc") />
	<cfset sVars.sForecast = xmlSearch(sVars.xmlDoc, "/weather/dayf") />
	<cfset sVars.sWeather = structNew() />
	<cfset sVars.sWeather.sLocation = structNew() />
	<cfset sVars.sWeather.sCurrentConditions = structNew() />
	<cfset sVars.sWeather.sForecast = structNew() />
	<cfset sVars.aLastUpdate = arrayNew(1) />
	<cfset sVars.cLastUpdate = "" />
	<cfset sVars.aForecastLastUpdate = arrayNew(1) />
	<cfset sVars.cForecastLastUpdate = "" />
	
	<cfset sVars.sWeather.sProperties.locale = sVars.sProperties[1].locale.XmlText />
	<cfset sVars.sWeather.sProperties.form = sVars.sProperties[1].form.XmlText />
	<cfset sVars.sWeather.sProperties.temperature = sVars.sProperties[1].ut.XmlText />
	<cfset sVars.sWeather.sProperties.distance = sVars.sProperties[1].ud.XmlText />
	<cfset sVars.sWeather.sProperties.speed = sVars.sProperties[1].us.XmlText />
	<cfset sVars.sWeather.sProperties.pressure = sVars.sProperties[1].up.XmlText />
	<cfset sVars.sWeather.sProperties.rain = sVars.sProperties[1].ur.XmlText />
	<cfset sVars.sWeather.sProperties.url = arguments.cUrl />
	
	<cfset sVars.sWeather.sLocation.id = sVars.sLocation[1].XmlAttributes.id />
	<cfset sVars.sWeather.sLocation.city = sVars.sLocation[1].dnam.Xmltext />
	<cfset sVars.sWeather.sLocation.name = sVars.sLocation[1].dnam.XmlText />
	<cfset sVars.sWeather.sLocation.time = sVars.sLocation[1].tm.XmlText />
	<cfset sVars.sWeather.sLocation.latitude = sVars.sLocation[1].lat.XmlText />
	<cfset sVars.sWeather.sLocation.longitude = sVars.sLocation[1].lon.XmlText />
	<cfset sVars.sWeather.sLocation.sunrise = sVars.sLocation[1].sunr.XmlText />
	<cfset sVars.sWeather.sLocation.sunset = sVars.sLocation[1].suns.XmlText />
	<cfset sVars.sWeather.sLocation.timeZone = sVars.sLocation[1].zone.XmlText />
	
	<cfset sVars.sWeather.sCurrentConditions.lastUpdate = sVars.sCurrentConditions[1].lsup.XmlText />
	<!--- Last update date/time only without surrounding text --->
	<cfset sVars.aLastUpdate = ListToArray(sVars.sCurrentConditions[1].lsup.XmlText, " ") />
	<cfset sVars.cLastUpdate = sVars.aLastUpdate[1] & " " & sVars.aLastUpdate[2] & " " & sVars.aLastUpdate[3] />
	<cfif IsDate(sVars.cLastUpdate)>
		<cfset sVars.sWeather.sCurrentConditions.lastUpdateDateTime = sVars.cLastUpdate />
	<cfelse>
		<cfset sVars.sWeather.sCurrentConditions.lastUpdateDateTime = "" />
	</cfif>
	<!--- /Last update date/time only without surrounding text --->
	<cfset sVars.sWeather.sCurrentConditions.station = sVars.sCurrentConditions[1].obst.XmlText />
	<cfset sVars.sWeather.sCurrentConditions.temperature = sVars.sCurrentConditions[1].tmp.XmlText />
	<cfset sVars.sWeather.sCurrentConditions.feelsLike = sVars.sCurrentConditions[1].flik.XmlText />
	<cfset sVars.sWeather.sCurrentConditions.description = sVars.sCurrentConditions[1].t.XmlText />
	<cfset sVars.sWeather.sCurrentConditions.icon = sVars.sCurrentConditions[1].icon.XmlText />
	<cfset sVars.sWeather.sCurrentConditions.lastUpdate = sVars.sCurrentConditions[1].lsup.XmlText />
	<cfset sVars.sWeather.sCurrentConditions.barIndex = sVars.sCurrentConditions[1].bar.r.XmlText />
	<cfset sVars.sWeather.sCurrentConditions.barDescription = sVars.sCurrentConditions[1].bar.d.XmlText />
	<cfset sVars.sWeather.sCurrentConditions.windSpeed = sVars.sCurrentConditions[1].wind.s.XmlText />
	<cfset sVars.sWeather.sCurrentConditions.windDirection = sVars.sCurrentConditions[1].wind.t.XmlText />
	<cfset sVars.sWeather.sCurrentConditions.windDegrees = sVars.sCurrentConditions[1].wind.d.XmlText />
	<cfset sVars.sWeather.sCurrentConditions.windGust = sVars.sCurrentConditions[1].wind.gust.XmlText />
	<cfset sVars.sWeather.sCurrentConditions.humidity = sVars.sCurrentConditions[1].hmid.XmlText />
	<cfset sVars.sWeather.sCurrentConditions.visibility = sVars.sCurrentConditions[1].vis.XmlText />
	<cfset sVars.sWeather.sCurrentConditions.uvindex = sVars.sCurrentConditions[1].uv.i.XmlText />
	<cfset sVars.sWeather.sCurrentConditions.uvDescription = sVars.sCurrentConditions[1].uv.t.XmlText />
	<cfset sVars.sWeather.sCurrentConditions.dewpoint = sVars.sCurrentConditions[1].dewp.XmlText />
	
	<cfset sVars.sWeather.sForecast.lastupdate = sVars.sForecast[1].lsup.XmlText />
	<!--- Last update date/time only without surrounding text --->
	<cfset sVars.aForecastLastUpdate = ListToArray(sVars.sForecast[1].lsup.XmlText, " ") />
	<cfset sVars.cForecastLastUpdate = sVars.aForecastLastUpdate[1] & " " & sVars.aForecastLastUpdate[2] & " " & sVars.aForecastLastUpdate[3] />
	<cfif IsDate(sVars.cForecastLastUpdate)>
		<cfset sVars.sWeather.sForecast.lastUpdateDateTime = sVars.cForecastLastUpdate />
	<cfelse>
		<cfset sVars.sWeather.sForecast.lastUpdateDateTime = "" />
	</cfif>
	<!--- /Last update date/time only without surrounding text --->
	<cfloop from="0" to="#arguments.iDaysForecast - 1#" index="i">
		<cfset sVars.sWeather.sForecast["sDay" & i] = structNew() />
		<cfset sVars.sWeather.sForecast["sDay" & i].dayNumber = sVars.sForecast[1].day[i + 1].XmlAttributes.d />
		<cfset sVars.sWeather.sForecast["sDay" & i].weekDay = sVars.sForecast[1].day[i + 1].XmlAttributes.t />
		<cfset sVars.sWeather.sForecast["sDay" & i].date = sVars.sForecast[1].day[i + 1].XmlAttributes.dt />
		<cfset sVars.sWeather.sForecast["sDay" & i].temperatureHigh = sVars.sForecast[1].day[i + 1].hi.XmlText />
		<cfset sVars.sWeather.sForecast["sDay" & i].temperatureLow = sVars.sForecast[1].day[i + 1].low.XmlText />
		<cfset sVars.sWeather.sForecast["sDay" & i].sunrise = sVars.sForecast[1].day[i + 1].sunr.XmlText />
		<cfset sVars.sWeather.sForecast["sDay" & i].sunset = sVars.sForecast[1].day[i + 1].suns.XmlText />
		<cfset sVars.sWeather.sForecast["sDay" & i].day = structNew() />
		<cfset sVars.sWeather.sForecast["sDay" & i].day.icon = sVars.sForecast[1].day[i + 1].part[1].icon.XmlText />
		<cfset sVars.sWeather.sForecast["sDay" & i].day.description = sVars.sForecast[1].day[i + 1].part[1].t.XmlText />
		<cfset sVars.sWeather.sForecast["sDay" & i].day.windSpeed = sVars.sForecast[1].day[i + 1].part[1].wind.s.XmlText />
		<cfset sVars.sWeather.sForecast["sDay" & i].day.windDirection = sVars.sForecast[1].day[i + 1].part[1].wind.t.XmlText />
		<cfset sVars.sWeather.sForecast["sDay" & i].day.windDegrees = sVars.sForecast[1].day[i + 1].part[1].wind.d.XmlText />
		<cfset sVars.sWeather.sForecast["sDay" & i].day.windGust = sVars.sForecast[1].day[i + 1].part[1].wind.gust.XmlText />
		<cfset sVars.sWeather.sForecast["sDay" & i].day.precipitation = sVars.sForecast[1].day[i + 1].part[1].ppcp.XmlText />
		<cfset sVars.sWeather.sForecast["sDay" & i].day.humidity = sVars.sForecast[1].day[i + 1].part[1].hmid.XmlText />
		<cfset sVars.sWeather.sForecast["sDay" & i].night = structNew() />
		<cfset sVars.sWeather.sForecast["sDay" & i].night.icon = sVars.sForecast[1].day[i + 1].part[2].icon.XmlText />
		<cfset sVars.sWeather.sForecast["sDay" & i].night.description = sVars.sForecast[1].day[i + 1].part[2].t.XmlText />
		<cfset sVars.sWeather.sForecast["sDay" & i].night.windSpeed = sVars.sForecast[1].day[i + 1].part[2].wind.s.XmlText />
		<cfset sVars.sWeather.sForecast["sDay" & i].night.windDirection = sVars.sForecast[1].day[i + 1].part[2].wind.t.XmlText />
		<cfset sVars.sWeather.sForecast["sDay" & i].night.windDegrees = sVars.sForecast[1].day[i + 1].part[2].wind.d.XmlText />
		<cfset sVars.sWeather.sForecast["sDay" & i].night.windGust = sVars.sForecast[1].day[i + 1].part[2].wind.gust.XmlText />
		<cfset sVars.sWeather.sForecast["sDay" & i].night.precipitation = sVars.sForecast[1].day[i + 1].part[2].ppcp.XmlText />
		<cfset sVars.sWeather.sForecast["sDay" & i].night.humidity = sVars.sForecast[1].day[i + 1].part[2].hmid.XmlText />
	</cfloop>
	
	<cfreturn sVars.sWeather />
</cffunction>